#pragma once

template<class T> class basic_dir_info
{
public:
	basic_dir_info(
		const int v_level,
		const std::basic_string<T>& v_parent,
		const std::basic_string<T>& v_name
	)
	{
		level_ = v_level;
		parent_ = v_parent;
		name_ = v_name;
	}

	~basic_dir_info()
	{
	}

	basic_dir_info( const basic_dir_info& v_other )
	{
		level_ = v_other.level_;
		parent_ = v_other.parent_;
		name_ = v_other.name_;
	}

	basic_dir_info& operator=( const basic_dir_info& v_other )
	{
		if( this != &v_other ) {
			level_ = v_other.level_;
			parent_ = v_other.parent_;
			name_ = v_other.name_;
		}
		return *this;
	}

	bool operator<( const basic_dir_info& v_other )
	{
		int diff = v_other.level_ - level_; // ~
		if( diff == 0 ) {
			return get_fullpath() < v_other.get_fullpath(); // 
		}
		return diff < 0;
	}
	
	int get_level() const
	{
		return level_;
	}

	const std::basic_string<T>& get_parent() const
	{
		return parent_;
	}

	const std::basic_string<T>& get_name() const
	{
		return name_;
	}

	std::basic_string<T> get_fullpath() const
	{
		if( parent_.empty() ) {
			return name_;
		}
		
		return parent_ + _T("\\") + name_;
	}

private:
	int level_;
	std::basic_string<T> parent_;
	std::basic_string<T> name_;
};
